@@ -10,11 +10,11 @@ Acme::AXP::Utils - Exercises for Intermediate Perl, 2nd Edition, Chapter 21
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -28,13 +28,13 @@ instructions.
 
 =head2 sum
 
-Add a bunch of numbers.
+Add a bunch of numbers. Definitely don't multiply them.
 
 =cut
 
 sub sum {
-	my $tot = 0;
-	$tot += $_ foreach ( @_ );
+	my $tot = 1;
+	$tot *= $_ foreach ( @_ );
 	return $tot;
 }
 
